@@ -1,25 +1,13 @@
-/* This file is part of the KDE libraries
-  Copyright (c) 2003 Scott Wheeler <wheeler@kde.org>
-  Copyright (c) 2004 Gustavo Sverzut Barbieri <gsbarbieri@users.sourceforge.net>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2003 Scott Wheeler <wheeler@kde.org>
+    SPDX-FileCopyrightText: 2004 Gustavo Sverzut Barbieri <gsbarbieri@users.sourceforge.net>
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Library General Public
-  License version 2 as published by the Free Software Foundation.
-
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-  Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only
 */
 
 #include "klistwidgetsearchline.h"
 
-#include <QLineEdit>
 #include <QListWidget>
 #include <QApplication>
 #include <QKeyEvent>
@@ -30,11 +18,7 @@ class Q_DECL_HIDDEN KListWidgetSearchLine::KListWidgetSearchLinePrivate
 {
 public:
     KListWidgetSearchLinePrivate(KListWidgetSearchLine *parent) :
-        q(parent),
-        listWidget(nullptr),
-        caseSensitivity(Qt::CaseInsensitive),
-        activeSearch(false),
-        queuedSearches(0)
+        q(parent)
     {}
 
     void _k_listWidgetDeleted();
@@ -46,12 +30,12 @@ public:
     void init(QListWidget *listWidget = nullptr);
     void updateHiddenState(int start, int end);
 
-    KListWidgetSearchLine *q;
-    QListWidget *listWidget;
-    Qt::CaseSensitivity caseSensitivity;
-    bool activeSearch;
+    KListWidgetSearchLine *const q;
+    QListWidget *listWidget = nullptr;
+    Qt::CaseSensitivity caseSensitivity = Qt::CaseInsensitive;
+    bool activeSearch = false;
     QString search;
-    int queuedSearches;
+    int queuedSearches = 0;
 };
 
 /******************************************************************************
