@@ -1,29 +1,14 @@
 /*
- * This file is part of the KDE project
- * Copyright (C) 2007-2008 Rafael Fernández López <ereslibre@kde.org>
- * Copyright (C) 2008 Kevin Ottens <ervin@kde.org>
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
- */
+    This file is part of the KDE project
+    SPDX-FileCopyrightText: 2007-2008 Rafael Fernández López <ereslibre@kde.org>
+    SPDX-FileCopyrightText: 2008 Kevin Ottens <ervin@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #include "kwidgetitemdelegate.h"
 #include "kwidgetitemdelegate_p.h"
 
-#include <QEvent>
-#include <QHoverEvent>
 #include <QCursor>
 #include <QTimer>
 #include <QPainter>
@@ -43,11 +28,7 @@ Q_DECLARE_METATYPE(QList<QEvent::Type>)
 //@cond PRIVATE
 KWidgetItemDelegatePrivate::KWidgetItemDelegatePrivate(KWidgetItemDelegate *q, QObject *parent)
     : QObject(parent)
-    , itemView(nullptr)
     , widgetPool(new KWidgetItemDelegatePool(q))
-    , model(nullptr)
-    , selectionModel(nullptr)
-    , viewDestroyed(false)
     , q(q)
 {
 }
@@ -93,7 +74,8 @@ void KWidgetItemDelegatePrivate::_k_slotDataChanged(const QModelIndex &topLeft,
 
 void KWidgetItemDelegatePrivate::_k_slotLayoutChanged()
 {
-    foreach (QWidget *widget, widgetPool->invalidIndexesWidgets()) {
+    const auto lst = widgetPool->invalidIndexesWidgets();
+    for (QWidget *widget : lst) {
         widget->setVisible(false);
     }
     QTimer::singleShot(0, this, SLOT(initializeModel()));
@@ -107,10 +89,12 @@ void KWidgetItemDelegatePrivate::_k_slotModelReset()
 
 void KWidgetItemDelegatePrivate::_k_slotSelectionChanged(const QItemSelection &selected, const QItemSelection &deselected)
 {
-    foreach (const QModelIndex &index, selected.indexes()) {
+    const auto lstSelected = selected.indexes();
+    for (const QModelIndex &index : lstSelected) {
         widgetPool->findWidgets(index, optionView(index));
     }
-    foreach (const QModelIndex &index, deselected.indexes()) {
+    const auto lstDeselected = deselected.indexes();
+    for (const QModelIndex &index : lstDeselected) {
         widgetPool->findWidgets(index, optionView(index));
     }
 }
@@ -121,11 +105,11 @@ void KWidgetItemDelegatePrivate::updateRowRange(const QModelIndex &parent, int s
     while (i <= end) {
         for (int j = 0; j < model->columnCount(parent); ++j) {
             const QModelIndex index = model->index(i, j, parent);
-            QList<QWidget *> widgetList = widgetPool->findWidgets(index, optionView(index), isRemoving ? KWidgetItemDelegatePool::NotUpdateWidgets
+            const QList<QWidget *> widgetList = widgetPool->findWidgets(index, optionView(index), isRemoving ? KWidgetItemDelegatePool::NotUpdateWidgets
                                           : KWidgetItemDelegatePool::UpdateWidgets);
             if (isRemoving) {
                 widgetPool->d->allocatedWidgets.removeAll(widgetList);
-                foreach (QWidget *widget, widgetList) {
+                for (QWidget *widget : widgetList) {
                     const QModelIndex idx = widgetPool->d->widgetInIndex[widget];
                     widgetPool->d->usedWidgets.remove(idx);
                     widgetPool->d->widgetInIndex.remove(widget);
@@ -151,6 +135,7 @@ void KWidgetItemDelegatePrivate::initializeModel(const QModelIndex &parent)
     if (!model) {
         return;
     }
+
     for (int i = 0; i < model->rowCount(parent); ++i) {
         for (int j = 0; j < model->columnCount(parent); ++j) {
             const QModelIndex index = model->index(i, j, parent);
@@ -211,7 +196,7 @@ QPersistentModelIndex KWidgetItemDelegate::focusedIndex() const
     return d->itemView->indexAt(pos);
 }
 
-#ifndef KITEMVIEWS_NO_DEPRECATED
+#if KITEMVIEWS_BUILD_DEPRECATED_SINCE(4, 2)
 void KWidgetItemDelegate::paintWidgets(QPainter *painter, const QStyleOptionViewItem &option,
                                        const QPersistentModelIndex &index) const
 {
@@ -275,7 +260,8 @@ bool KWidgetItemDelegatePrivate::eventFilter(QObject *watched, QEvent *event)
     case QEvent::FocusIn:
     case QEvent::FocusOut:
         if (qobject_cast<QAbstractItemView *>(watched)) {
-            foreach (const QModelIndex &index, selectionModel->selectedIndexes()) {
+            const auto lst = selectionModel->selectedIndexes();
+            for (const QModelIndex &index : lst) {
                 if (index.isValid()) {
                     widgetPool->findWidgets(index, optionView(index));
                 }
@@ -292,7 +278,7 @@ bool KWidgetItemDelegatePrivate::eventFilter(QObject *watched, QEvent *event)
 
 void KWidgetItemDelegate::setBlockedEventTypes(QWidget *widget, QList<QEvent::Type> types) const
 {
-    widget->setProperty("goya:blockedEventTypes", qVariantFromValue(types));
+    widget->setProperty("goya:blockedEventTypes", QVariant::fromValue(types));
 }
 
 QList<QEvent::Type> KWidgetItemDelegate::blockedEventTypes(QWidget *widget) const
@@ -300,5 +286,10 @@ QList<QEvent::Type> KWidgetItemDelegate::blockedEventTypes(QWidget *widget) cons
     return widget->property("goya:blockedEventTypes").value<QList<QEvent::Type> >();
 }
 
+void KWidgetItemDelegate::resetModel()
+{
+   d->_k_slotModelReset();
+}
+
 #include "moc_kwidgetitemdelegate.cpp"
 #include "moc_kwidgetitemdelegate_p.cpp"
