@@ -17,8 +17,8 @@
 #include <QApplication>
 #include <QInputEvent>
 #include <QAbstractProxyModel>
-#include <QDebug>
 
+#include <kitemviews_debug.h>
 #include "kwidgetitemdelegate.h"
 #include "kwidgetitemdelegate_p.h"
 
@@ -42,13 +42,12 @@ public:
     bool eventFilter(QObject *watched, QEvent *event) override;
 
 private:
-    KWidgetItemDelegatePoolPrivate *poolPrivate;
+    KWidgetItemDelegatePoolPrivate *const poolPrivate;
 };
 
 KWidgetItemDelegatePoolPrivate::KWidgetItemDelegatePoolPrivate(KWidgetItemDelegate *d)
     : delegate(d)
     , eventListener(new KWidgetItemDelegateEventListener(this))
-    , clearing(false)
 {
 }
 
@@ -148,7 +147,7 @@ bool KWidgetItemDelegateEventListener::eventFilter(QObject *watched, QEvent *eve
     QWidget *widget = static_cast<QWidget *>(watched);
 
     if (event->type() == QEvent::Destroy && !poolPrivate->clearing) {
-        qWarning() << "User of KWidgetItemDelegate should not delete widgets created by createItemWidgets!";
+        qCWarning(KITEMVIEWS_LOG) << "User of KWidgetItemDelegate should not delete widgets created by createItemWidgets!";
         // assume the application has kept a list of widgets and tries to delete them manually
         // they have been reparented to the view in any case, so no leaking occurs
         poolPrivate->widgetInIndex.remove(widget);
@@ -170,7 +169,6 @@ bool KWidgetItemDelegateEventListener::eventFilter(QObject *watched, QEvent *eve
         break;
         case QEvent::Wheel: {
             QWheelEvent *wheelEvent = static_cast<QWheelEvent *>(event);
-#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
             QWheelEvent evt(viewport->mapFromGlobal(wheelEvent->position().toPoint()),
                             viewport->mapFromGlobal(wheelEvent->globalPosition().toPoint()),
                             wheelEvent->pixelDelta(), wheelEvent->angleDelta(),
@@ -178,11 +176,6 @@ bool KWidgetItemDelegateEventListener::eventFilter(QObject *watched, QEvent *eve
                             wheelEvent->phase(),
                             wheelEvent->inverted(),
                             wheelEvent->source());
-#else
-            QWheelEvent evt(viewport->mapFromGlobal(wheelEvent->globalPos()),
-                            wheelEvent->angleDelta().y(), wheelEvent->buttons(), wheelEvent->modifiers(),
-                            wheelEvent->orientation());
-#endif
             QApplication::sendEvent(viewport, &evt);
         }
         break;
@@ -193,10 +186,16 @@ bool KWidgetItemDelegateEventListener::eventFilter(QObject *watched, QEvent *eve
         case QEvent::TabletLeaveProximity: {
             QTabletEvent *tabletEvent = static_cast<QTabletEvent *>(event);
             QTabletEvent evt(event->type(), QPointF(viewport->mapFromGlobal(tabletEvent->globalPos())),
-                             tabletEvent->globalPosF(), tabletEvent->device(),
+                             tabletEvent->globalPosF(),
+#if QT_VERSION >= QT_VERSION_CHECK(5, 15, 0)
+                             tabletEvent->deviceType(),
+#else
+                             tabletEvent->device(),
+#endif
                              tabletEvent->pointerType(), tabletEvent->pressure(), tabletEvent->xTilt(),
                              tabletEvent->yTilt(), tabletEvent->tangentialPressure(), tabletEvent->rotation(),
-                             tabletEvent->z(), tabletEvent->modifiers(), tabletEvent->uniqueId());
+                             tabletEvent->z(), tabletEvent->modifiers(), tabletEvent->uniqueId(),
+                             tabletEvent->button(), tabletEvent->buttons());
             QApplication::sendEvent(viewport, &evt);
         }
         break;
